@@ -1,5 +1,4 @@
 import os
-
 from deep_utils.utils.os_utils.os_path import split_extension
 
 
@@ -15,10 +14,28 @@ class ModelCheckPoint:
                  loss=None,
                  optimizer=None,
                  scheduler=None,
-                 static_dict=None):
+                 static_dict=None,
+                 monitor_val=None):
+        """
+
+        :param model_path:
+        :param model:
+        :param monitor:
+        :param save_best_only:
+        :param overwrite:
+        :param verbose:
+        :param save_last:
+        :param loss:
+        :param optimizer:
+        :param scheduler:
+        :param static_dict:
+        :param monitor_val: monitoring value. For starting the checkpointer from a saved model,
+         by passing the monitoring value you preserve the best model.
+        """
         self.overwrite = overwrite
         self.model_path = model_path
         self.monitor_val = float('-inf') if monitor == 'max' else float('inf')
+        self.monitor_val = self.monitor_val if monitor_val is None else monitor_val
         self.save_best_only = save_best_only
         self.model = model
         self.loss = loss
@@ -30,8 +47,8 @@ class ModelCheckPoint:
         self.verbose = verbose
         self.save_last = save_last
         os.makedirs(os.path.split(model_path)[0], exist_ok=True)
-
-    def __call__(self, monitor_val):
+        print(f'[INFO] Initializing checkpointer with monitor-mode:{monitor} from monitor-val:{monitor_val}')
+    def __call__(self, monitor_val, **kwargs):
         self.epoch += 1
         if self.save_best_only:
             trigger = False
@@ -44,7 +61,7 @@ class ModelCheckPoint:
 
             if self.save_last:
                 last_path = split_extension(self.model_path, suffix="_last")
-                self._save(last_path, print_=False)
+                self._save(last_path, print_=False, monitor_val=monitor_val, **kwargs)
 
             if self.overwrite:
                 best_path = split_extension(self.model_path, suffix="_best")
@@ -52,21 +69,25 @@ class ModelCheckPoint:
                 best_path = split_extension(self.model_path, suffix="_" + str(self.epoch))
 
             if trigger:
-                self._save(best_path, print_=self.verbose)
+                self._save(best_path, print_=self.verbose, monitor_val=monitor_val, **kwargs)
         else:
             model_path = split_extension(self.model_path, suffix="_" + str(self.epoch))
-            self._save(model_path, print_=self.verbose)
+            self._save(model_path, print_=self.verbose, monitor_val=monitor_val, **kwargs)
 
-    def _save(self, model_path, print_):
+    def _save(self, model_path, print_, **extra):
         import torch
         save_dict = self.static_dict if self.static_dict is not None else dict()
+        save_dict.update(extra if extra is not None else dict())
         save_dict['model_state_dict'] = self.model.state_dict()
-        self._add_file(save_dict, 'optimizer', self.optimizer)
-        self._add_file(save_dict, 'scheduler', self.scheduler)
+        self._add_file(save_dict, 'optimizer', self.optimizer.state_dict())
+        self._add_file(save_dict, 'scheduler', self.scheduler.state_dict())
         self._add_file(save_dict, 'loss', self.loss)
         torch.save(save_dict, model_path)
         if print_:
-            print(f'[INFO] model is saved in {model_path}')
+            if "monitor_val" in extra:
+                print(f'[INFO] model is saved in {model_path} with monitor-val: {extra["monitor_val"]}')
+            else:
+                print(f'[INFO] model is saved in {model_path}')
 
     @staticmethod
     def _add_file(dict_, name, file):
