@@ -87,6 +87,34 @@ def split_xy_dir(x_in_dir,
     transfer_directory_items(y_in_dir, y_val_dir, val_labels,
                              mode=mode, remove_out_dir=remove_out_dir, skip_transfer=skip_transfer)
 
+def crawl_directory_dataset(dir_: str, ext_filter: list = None) -> Tuple[List[str], List[int], Dict]:
+    """
+    crawls a directory of classes and returns the full path of the items paths and their class names
+    :param dir_: path to directory of classes
+    :param ext_filter: extensions that will be passed and others will be dropped
+    :return: Tuple[List[str], List[int], Dict], x_list containing the paths, y_list containing the class_names, and
+    label_map dictionary.
+    """
+    print(f"[INFO] beginning to crawl {dir_}")
+    x, y = [], []
+    label_map = dict()
+    for cls_name in os.listdir(dir_):
+        cls_path = join(dir_, cls_name)
+        for item_name in os.listdir(cls_path):
+            item_path = join(cls_path, item_name)
+            name, ext = os.path.splitext(item_name)
+            if ext_filter is not None and ext not in ext_filter:
+                print(f"[INFO] {item_path} with {ext} is not in ext_filtering: {ext_filter}")
+                continue
+            x.append(item_path)
+            if cls_name not in label_map:
+                cls_index = len(label_map)
+                label_map[cls_name] = cls_index
+            else:
+                cls_index = label_map[cls_name]
+            y.append(cls_index)
+    print(f"[INFO] successfully crawled {dir_}")
+    return x, y, label_map
 
 def remove_create(dir_):
     import os
